@@ -24,7 +24,7 @@ class User(Model):
     is_admin: bool = field.BooleanField(default=False)
     is_staff: bool = field.BooleanField(default=False)
     groups: field.ManyToManyRelation[Group] = field.ManyToManyField(
-        "ohmyapi_auth.Group", related_name="users", through="user_groups"
+        "ohmyapi_auth.Group", related_name="users", through="usergroups"
     )
 
     class Schema:
